@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Mojo::IOLoop;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use base 'Mojolicious::Plugin';
 
@@ -38,10 +38,6 @@ Mojolicious::Plugin::SslAuth - SSL client certificate auth helper
 
 L<Mojolicous::Plugin::SslAuth> is a helper for authenticating client ssl certificates against CA's (certificate authorities)
 
-=head2 If using Mojolicious versions before 2.81
-
-L<0.05|http://backpan.perl.org/authors/id/T/TE/TEMPIRE/Mojolicious-Plugin-SslAuth-0.05.tar.gz>
-
 =head1 USAGE
 
     use Mojolicious::Lite;
@@ -49,13 +45,14 @@ L<0.05|http://backpan.perl.org/authors/id/T/TE/TEMPIRE/Mojolicious-Plugin-SslAut
     plugin 'ssl_auth';
 
     get '/' => sub {
-        my $self = shift;
+      my $self = shift;
 
-        return $self->render_text('ok')
-          if $self->ssl_auth(
-          {return 1 if shift->peer_certificate('commonName') eq 'client'});
+      return $self->render_text('ok')
+        if $self->ssl_auth(
+          {return 1 if shift->peer_certificate('commonName') eq 'client'}
+        );
 
-        $self->render_text('commonName not matched');
+      $self->render_text('commonName not matched');
     };
 
     app->start;
@@ -64,6 +61,16 @@ L<IO::Socket::SSL> connection passed as parameter.
 
 See L<IO::Socket::SSL> for available methods. (You're most likely looking for ->peer_certificate and/or ->get_cipher)
 
+=over
+
+=item Older versions of Mojolicious
+
+For Mojolicious versions < 2.81, use Mojolicious::Plugin::SslAuth 0.05
+
+For Mojolicious versions < 1.13, use Mojolicious::Plugin::SslAuth 0.02
+
+=back
+
 =head1 METHODS
 
 L<Mojolicious::Plugin::SslAuth> inherits all methods from
@@ -85,7 +92,7 @@ L<http://github.com/tempire/mojolicious-plugin-sslauth>
 
 =head1 VERSION
 
-0.06
+0.07
 
 =head1 AUTHOR
 
